<?php
/**
 * Extra custom header and footer: functions and globals for 'Forums' location
 *
 * @package extrahf
 * @version 2009-06-15 beta
 * @author dervan
 * @license BSD
 */

defined('SED_CODE') or die('Wrong URL.');

/**
 * Updates $location with forum section id or category
 *
 * @global $cfg
 * @global $usr
 * @global $location
 * @global $exhf_part
 * @global $exhf_what
 * @global $exhf_sectid
 * @global $exhf_category
 * @param string $part Part is 'header' or 'footer'
 */
function exhf_update_location($part)
{
	global $cfg, $usr, $location, $exhf_part, $exhf_what, $exhf_sectid, $exhf_category;

	if (!defined('SED_FORUMS') || !empty($exhf_part))
	{
		return;
	}

	$uri = "skins/{$usr['skin']}/$part";

	if (empty($exhf_what))
	{
		if (file_exists("$uri.forums.sections.tpl"))
		{
			$location = 'forums.sections';
			$exhf_part = $part;
		}
		return;
	}

	switch ($cfg['plugin']['extrahf']["exhf_c_frm$part"])
	{
		case 'section_id or category':
			$sufx_a = array(&$exhf_sectid, &$exhf_category,);
		break;

		case 'category or section_id':
			$sufx_a = array(&$exhf_category, &$exhf_sectid,);
		break;

		case 'section_id':
			$sufx_a = array(&$exhf_sectid,);
		break;

		case 'category':
			$sufx_a = array(&$exhf_category,);
		break;

		case 'default':
		default:
			return;
		break;
	}

	$what_a = array("forums.$exhf_what", 'forums',);
	foreach ($sufx_a as $sufx)
	{
		if (!empty($sufx))
		{
			foreach ($what_a as $what)
			{
				if (file_exists("$uri.$what.$sufx.tpl"))
				{
					$location = "$what.$sufx";
					$exhf_part = $part;
					return;
				}
			}
		}
	}
	if (file_exists("$uri.forums.$exhf_what.tpl"))
	{
		$location = "forums.$exhf_what";
		$exhf_part = $part;
		return;
	}
}

/**
 * Recovers native $location (see forums.php)
 *
 * @global $location
 * @global $exhf_part
 * @param string $part Part is 'header' or 'footer'
 */
function exhf_recover_location($part)
{
	global $location, $exhf_part;

	if (defined('SED_FORUMS') && !empty($exhf_part) && $exhf_part == $part)
	{
		$location = 'Forums';
		$exhf_part = '';
	}
}

/**
 * Returns normalized code
 *
 * @global $lang
 * @global $sed_translit
 * @param string $code Code of category
 * @return string
 */
function exhf_normalize_code($code)
{
	global $lang, $sed_translit;

	if ($lang != 'en' && is_array($sed_translit))
	{
		$code = strtr($code, $sed_translit);
	}
	$code = strtr($code, ' .', '__');
	$code = preg_replace('#[^a-zA-Z0-9\-_]#', '', $code);

	return mb_strtolower($code);
}

/**
 * Globals
 */
if (!defined('SED_FORUMS'))
{
	return;
}
$exhf_part = '';
switch ($m)
{
	case 'editpost':
		$exhf_what = $m;
		$exhf_sectid = "fs$fp_sectionid";
	break;

	case 'newtopic':
	case 'posts':
	case 'topics':
		$exhf_what = $m;
		$exhf_sectid = "fs$s";
	break;

	default:
		$exhf_what = $exhf_sectid = '';
	break;
}
$exhf_category = exhf_normalize_code($fs_category);
?>