<?php
/**
 * Extra custom header and footer: functions and globals for 'Pages' location with defined('SED_PAGE')
 *
 * @package extrahf
 * @version 2009-06-15 beta
 * @author dervan
 * @license BSD
 */

defined('SED_CODE') or die('Wrong URL.');

/**
 * Updates $location with page alias or category
 *
 * @global $cfg
 * @global $usr
 * @global $location
 * @global $exhf_part
 * @global $exhf_what
 * @global $exhf_alias
 * @global $exhf_category
 * @param string $part Part is 'header' or 'footer'
 */
function exhf_update_location($part)
{
	global $cfg, $usr, $location, $exhf_part, $exhf_what, $exhf_alias, $exhf_category;

	if (!defined('SED_PAGE') || !empty($exhf_part))
	{
		return;
	}

	switch ($cfg['plugin']['extrahf']["exhf_c_pag$part"])
	{
		case 'alias or category':
			$conf_a = array(
				array('is_alias' => true, 'attr' => &$exhf_alias,),
				array('is_alias' => false, 'attr' => &$exhf_category,),
				);
		break;

		case 'category or alias':
			$conf_a = array(
				array('is_alias' => false, 'attr' => &$exhf_category,),
				array('is_alias' => true, 'attr' => &$exhf_alias,),
				);
		break;

		case 'alias':
			$conf_a = array(
				array('is_alias' => true, 'attr' => &$exhf_alias,),
				);
		break;

		case 'category':
			$conf_a = array(
				array('is_alias' => false, 'attr' => &$exhf_category,),
				);
		break;

		case 'default':
		default:
			return;
		break;
	}

	$uri = "skins/{$usr['skin']}/$part";
	$what_a = empty($exhf_what) ? array('pages',) : array("pages.$exhf_what", 'pages',);
	foreach ($conf_a as $sufx_a)
	{
		$sufx =& $sufx_a['attr'];
		if (!empty($sufx))
		{
			if ($sufx_a['is_alias'])
			{
				if (file_exists("$uri.pages.$sufx.tpl"))
				{
					$location = "pages.$sufx";
					$exhf_part = $part;
					return;
				}
			}
			else
			{
				foreach ($what_a as $what)
				{
					if (file_exists("$uri.$what.$sufx.tpl"))
					{
						$location = "$what.$sufx";
						$exhf_part = $part;
						return;
					}
				}
			}
		}
	}
	if (!empty($exhf_what) && file_exists("$uri.pages.$exhf_what.tpl"))
	{
		$location = "pages.$exhf_what";
		$exhf_part = $part;
		return;
	}
}

/**
 * Recovers native $location (see page.php)
 *
 * @global $location
 * @global $exhf_part
 * @param string $part Part is 'header' or 'footer'
 */
function exhf_recover_location($part)
{
	global $location, $exhf_part;

	if (defined('SED_PAGE') && !empty($exhf_part) && $exhf_part == $part)
	{
		$location = 'Pages';
		$exhf_part = '';
	}
}

/**
 * Returns normalized code
 *
 * @global $lang
 * @global $sed_translit
 * @param string $code Code of category
 * @return string
 */
function exhf_normalize_code($code)
{
	global $lang, $sed_translit;

	if ($lang != 'en' && is_array($sed_translit))
	{
		$code = strtr($code, $sed_translit);
	}
	$code = strtr($code, ' .', '__');
	$code = preg_replace('#[^a-zA-Z0-9\-_]#', '', $code);

	return mb_strtolower($code);
}

/**
 * Globals
 */
if (!defined('SED_PAGE'))
{
	return;
}
$exhf_part = '';
switch ($m)
{
	case 'add':
	case 'edit':
		$exhf_what = $m;
		$exhf_alias = '';
	break;

	default:
		$exhf_what = '';
		$exhf_alias = mb_strtolower($pag['page_alias']);
	break;
}
$exhf_category = exhf_normalize_code($sed_cat[isset($newpagecat) ? $newpagecat : $pag['page_cat']]['tpl']);
?>